==> atlantic-2.0.1-sources.jar: org/mule/commons/atlantic/lambda/consumer/HexaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.HexaFunction;

/**
 * Represents an operation that accepts six input arguments and returns no result.  This is the six-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code HexaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 * @param <F> The type of the sixth argument to the operation.
 */
@FunctionalInterface
public interface HexaConsumer<A, B, C, D, E, F> extends AtlanticConsumer<HexaFunction<A, B, C, D, E, F, Void>> {

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @param f The sixth input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e, F f) throws Throwable;

    @Override
    default HexaFunction<A, B, C, D, E, F, Void> toFunction() {
        return (a, b, c, d, e, f) -> {
            accept(a, b, c, d, e, f);
            return null;
        };
    }
}

==> atlantic-3.1.0-sources.jar: org/mule/commons/atlantic/lambda/consumer/HexaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.HexaFunction;
import org.mule.commons.atlantic.lambda.supplier.Supplier;

/**
 * Represents an operation that accepts six input arguments and returns no result.  This is the six-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code HexaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 * @param <F> The type of the sixth argument to the operation.
 */
@FunctionalInterface
public interface HexaConsumer<A, B, C, D, E, F> extends AtlanticConsumer<A, PentaConsumer<B, C, D, E, F>, HexaFunction<A, B, C, D, E, F, Void>> {

    @Override
    default PentaConsumer<B, C, D, E, F> downgrade(Supplier<A> supplier) {
        return (b, c, d, e, f) -> accept(supplier.get(), b, c, d, e, f);
    }

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @param f The sixth input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e, F f) throws Throwable;

    @Override
    default HexaFunction<A, B, C, D, E, F, Void> toFunction() {
        return (a, b, c, d, e, f) -> {
            accept(a, b, c, d, e, f);
            return null;
        };
    }
}
